==> kconfig-5.80.0.tgz: include/KF5/KConfigCore/kconfigcore_export.h <==

#ifndef KCONFIGCORE_EXPORT_H
#define KCONFIGCORE_EXPORT_H

#ifdef KCONFIGCORE_STATIC_DEFINE
#  define KCONFIGCORE_EXPORT
#  define KCONFIGCORE_NO_EXPORT
#else
#  ifndef KCONFIGCORE_EXPORT
#    ifdef KF5ConfigCore_EXPORTS
        /* We are building this library */
#      define KCONFIGCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KCONFIGCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KCONFIGCORE_NO_EXPORT
#    define KCONFIGCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KCONFIGCORE_DECL_DEPRECATED
#  define KCONFIGCORE_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCONFIGCORE_DECL_DEPRECATED_EXPORT
#  define KCONFIGCORE_DECL_DEPRECATED_EXPORT KCONFIGCORE_EXPORT KCONFIGCORE_DECL_DEPRECATED
#endif

#ifndef KCONFIGCORE_DECL_DEPRECATED_NO_EXPORT
#  define KCONFIGCORE_DECL_DEPRECATED_NO_EXPORT KCONFIGCORE_NO_EXPORT KCONFIGCORE_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCONFIGCORE_NO_DEPRECATED
#    define KCONFIGCORE_NO_DEPRECATED
#  endif
#endif

#define KCONFIGCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KCONFIGCORE_NO_DEPRECATED) && !defined(KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCONFIGCORE_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCONFIGCORE_NO_DEPRECATED_WARNINGS) && !defined(KCONFIGCORE_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCONFIGCORE_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCONFIGCORE_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCONFIGCORE_NO_DEPRECATED)
#  undef KCONFIGCORE_DEPRECATED
#  define KCONFIGCORE_DEPRECATED_EXPORT KCONFIGCORE_EXPORT
#  define KCONFIGCORE_DEPRECATED_NO_EXPORT KCONFIGCORE_NO_EXPORT
#elif defined(KCONFIGCORE_NO_DEPRECATED_WARNINGS)
#  define KCONFIGCORE_DEPRECATED
#  define KCONFIGCORE_DEPRECATED_EXPORT KCONFIGCORE_EXPORT
#  define KCONFIGCORE_DEPRECATED_NO_EXPORT KCONFIGCORE_NO_EXPORT
#else
#  define KCONFIGCORE_DEPRECATED KCONFIGCORE_DECL_DEPRECATED
#  define KCONFIGCORE_DEPRECATED_EXPORT KCONFIGCORE_DECL_DEPRECATED_EXPORT
#  define KCONFIGCORE_DEPRECATED_NO_EXPORT KCONFIGCORE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCONFIGCORE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCONFIGCORE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCONFIGCORE_NO_DEPRECATED
#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55000
#endif
#ifdef KCONFIGCORE_NO_DEPRECATED_WARNINGS
#  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCONFIGCORE_DEPRECATED_WARNINGS_SINCE
#  ifdef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x55000
#  endif
#endif

#ifndef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCONFIGCORE_DEPRECATED
#  define KCONFIGCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCONFIGCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KCONFIGCORE_DEPRECATED_VERSION_4_0(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_4_0(text)
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KCONFIGCORE_DEPRECATED_VERSION_5_0(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_5_0(text)
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x51800
#  define KCONFIGCORE_DEPRECATED_VERSION_5_24(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_5_24(text)
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x52a00
#  define KCONFIGCORE_DEPRECATED_VERSION_5_42(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_5_42(text)
#endif
#define KCONFIGCORE_DEPRECATED_VERSION_4(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_4_##minor(text)
#define KCONFIGCORE_DEPRECATED_VERSION_5(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_5_##minor(text)
#define KCONFIGCORE_DEPRECATED_VERSION(major, minor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KCONFIGCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)

#endif /* KCONFIGCORE_EXPORT_H */

==> kconfig-5.85.0.tgz: include/KF5/KConfigCore/kconfigcore_export.h <==

#ifndef KCONFIGCORE_EXPORT_H
#define KCONFIGCORE_EXPORT_H

#ifdef KCONFIGCORE_STATIC_DEFINE
#  define KCONFIGCORE_EXPORT
#  define KCONFIGCORE_NO_EXPORT
#else
#  ifndef KCONFIGCORE_EXPORT
#    ifdef KF5ConfigCore_EXPORTS
        /* We are building this library */
#      define KCONFIGCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KCONFIGCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KCONFIGCORE_NO_EXPORT
#    define KCONFIGCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KCONFIGCORE_DECL_DEPRECATED
#  define KCONFIGCORE_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCONFIGCORE_DECL_DEPRECATED_EXPORT
#  define KCONFIGCORE_DECL_DEPRECATED_EXPORT KCONFIGCORE_EXPORT KCONFIGCORE_DECL_DEPRECATED
#endif

#ifndef KCONFIGCORE_DECL_DEPRECATED_NO_EXPORT
#  define KCONFIGCORE_DECL_DEPRECATED_NO_EXPORT KCONFIGCORE_NO_EXPORT KCONFIGCORE_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCONFIGCORE_NO_DEPRECATED
#    define KCONFIGCORE_NO_DEPRECATED
#  endif
#endif

#define KCONFIGCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KCONFIGCORE_NO_DEPRECATED) && !defined(KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCONFIGCORE_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCONFIGCORE_NO_DEPRECATED_WARNINGS) && !defined(KCONFIGCORE_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCONFIGCORE_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCONFIGCORE_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCONFIGCORE_NO_DEPRECATED)
#  undef KCONFIGCORE_DEPRECATED
#  define KCONFIGCORE_DEPRECATED_EXPORT KCONFIGCORE_EXPORT
#  define KCONFIGCORE_DEPRECATED_NO_EXPORT KCONFIGCORE_NO_EXPORT
#elif defined(KCONFIGCORE_NO_DEPRECATED_WARNINGS)
#  define KCONFIGCORE_DEPRECATED
#  define KCONFIGCORE_DEPRECATED_EXPORT KCONFIGCORE_EXPORT
#  define KCONFIGCORE_DEPRECATED_NO_EXPORT KCONFIGCORE_NO_EXPORT
#else
#  define KCONFIGCORE_DEPRECATED KCONFIGCORE_DECL_DEPRECATED
#  define KCONFIGCORE_DEPRECATED_EXPORT KCONFIGCORE_DECL_DEPRECATED_EXPORT
#  define KCONFIGCORE_DEPRECATED_NO_EXPORT KCONFIGCORE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCONFIGCORE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCONFIGCORE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCONFIGCORE_NO_DEPRECATED
#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
#endif
#ifdef KCONFIGCORE_NO_DEPRECATED_WARNINGS
#  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCONFIGCORE_DEPRECATED_WARNINGS_SINCE
#  ifdef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x55500
#  endif
#endif

#ifndef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCONFIGCORE_DEPRECATED
#  define KCONFIGCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCONFIGCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KCONFIGCORE_DEPRECATED_VERSION_4_0(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_4_0(text)
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KCONFIGCORE_DEPRECATED_VERSION_5_0(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_5_0(text)
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x51800
#  define KCONFIGCORE_DEPRECATED_VERSION_5_24(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_5_24(text)
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x52a00
#  define KCONFIGCORE_DEPRECATED_VERSION_5_42(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_5_42(text)
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x55200
#  define KCONFIGCORE_DEPRECATED_VERSION_5_82(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_5_82(text)
#endif
#define KCONFIGCORE_DEPRECATED_VERSION_4(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_4_##minor(text)
#define KCONFIGCORE_DEPRECATED_VERSION_5(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_5_##minor(text)
#define KCONFIGCORE_DEPRECATED_VERSION(major, minor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KCONFIGCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCONFIGCORE_DEPRECATED_VERSION(major, minor, text)
#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KCONFIGCORE_EXPORT_H */


#ifndef ECM_GENERATEEXPORTHEADER_KCONFIGCORE_EXPORT_H
#define ECM_GENERATEEXPORTHEADER_KCONFIGCORE_EXPORT_H


#define KCONFIGCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KCONFIGCORE_NO_DEPRECATED) && !defined(KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCONFIGCORE_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCONFIGCORE_NO_DEPRECATED_WARNINGS) && !defined(KCONFIGCORE_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCONFIGCORE_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCONFIGCORE_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCONFIGCORE_NO_DEPRECATED)
#  undef KCONFIGCORE_DEPRECATED
#  define KCONFIGCORE_DEPRECATED_EXPORT KCONFIGCORE_EXPORT
#  define KCONFIGCORE_DEPRECATED_NO_EXPORT KCONFIGCORE_NO_EXPORT
#elif defined(KCONFIGCORE_NO_DEPRECATED_WARNINGS)
#  define KCONFIGCORE_DEPRECATED
#  define KCONFIGCORE_DEPRECATED_EXPORT KCONFIGCORE_EXPORT
#  define KCONFIGCORE_DEPRECATED_NO_EXPORT KCONFIGCORE_NO_EXPORT
#else
#  define KCONFIGCORE_DEPRECATED KCONFIGCORE_DECL_DEPRECATED
#  define KCONFIGCORE_DEPRECATED_EXPORT KCONFIGCORE_DECL_DEPRECATED_EXPORT
#  define KCONFIGCORE_DEPRECATED_NO_EXPORT KCONFIGCORE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCONFIGCORE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCONFIGCORE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCONFIGCORE_NO_DEPRECATED
#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
#endif
#ifdef KCONFIGCORE_NO_DEPRECATED_WARNINGS
#  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCONFIGCORE_DEPRECATED_WARNINGS_SINCE
#  ifdef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x55500
#  endif
#endif

#ifndef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCONFIGCORE_DEPRECATED
#  define KCONFIGCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCONFIGCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KCONFIGCORE_DEPRECATED_VERSION_4_0(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_4_0(text)
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KCONFIGCORE_DEPRECATED_VERSION_5_0(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_5_0(text)
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x51800
#  define KCONFIGCORE_DEPRECATED_VERSION_5_24(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_5_24(text)
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x52a00
#  define KCONFIGCORE_DEPRECATED_VERSION_5_42(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_5_42(text)
#endif

#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x55200
#  define KCONFIGCORE_DEPRECATED_VERSION_5_82(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGCORE_DEPRECATED_VERSION_5_82(text)
#endif
#define KCONFIGCORE_DEPRECATED_VERSION_4(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_4_##minor(text)
#define KCONFIGCORE_DEPRECATED_VERSION_5(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_5_##minor(text)
#define KCONFIGCORE_DEPRECATED_VERSION(major, minor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KCONFIGCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCONFIGCORE_DEPRECATED_VERSION(major, minor, text)
#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif


#endif /* ECM_GENERATEEXPORTHEADER_KCONFIGCORE_EXPORT_H */
